Coverage for src/configuraptor/__init__.py: 100%

1"""

2 Exposes TypedConfig and load_into for this library.

3"""

4

5# SPDX-FileCopyrightText: 2023-present Robin van der Noord <robinvandernoord@gmail.com>

6#

7# SPDX-License-Identifier: MIT

8 from .cls import TypedConfig, update

9 from .core import (

10 all_annotations,

11 check_and_convert_data,

12 convert_config,

13 ensure_types,

14 load_into,

15 load_into_class,

16 load_into_instance,

17)

18 from .dump import asdict, asjson, astoml, asyaml

19 from .postpone import postpone

20 from .singleton import Singleton, SingletonMeta

21

22 __all__ = [

23 # cls

24 "TypedConfig",

25 "update",

26 # singleton

27 "Singleton",

28 "SingletonMeta",

29 # core

30 "all_annotations",

31 "check_and_convert_data",

32 "convert_config",

33 "ensure_types",

34 "load_into",

35 "load_into_class",

36 "load_into_instance",

37 # postpone

38 "postpone",

39 # dump

40 "asdict",

41 "astoml",

42 "asyaml",

43 "asjson",

44]